# NARpyn

> A Python API library for NARS

<div align="center">

<img src="https://raw.githubusercontent.com/ntoxeg/narpyn/main/logo.png" alt="NARpyn logo" width="500" role="img">

|         |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
|---------| |
| CI/CD   | [![CI - Test](https://github.com/ntoxeg/narpyn/actions/workflows/test.yml/badge.svg)](https://github.com/ntoxeg/narpyn/actions/workflows/test.yml) [![CD - Build](https://github.com/ntoxeg/narpyn/actions/workflows/build.yml/badge.svg)](https://github.com/ntoxeg/narpyn/actions/workflows/build.yml) [![CI - Coverage](https://raw.githubusercontent.com/ntoxeg/narpyn/gh-pages/coverage.svg?raw=true)](https://github.com/ntoxeg/narpyn/actions/workflows/test.yml)                                                                                                                                                                                                                                                                                          |
| Docs    | [![Docs - Release](https://github.com/ntoxeg/narpyn/actions/workflows/docs-release.yml/badge.svg)](https://github.com/ntoxeg/narpyn/actions/workflows/docs-release.yml) [![Docs - Dev](https://github.com/ntoxeg/narpyn/actions/workflows/docs-dev.yml/badge.svg)](https://github.com/ntoxeg/narpyn/actions/workflows/docs-dev.yml)                                                                                                                                                                                                                                                                                                                                                                                                                               |
| Package | [![PyPI - Version](https://img.shields.io/pypi/v/narpyn?logo=pypi&label=PyPI&logoColor=gold)](https://pypi.org/project/narpyn/) [![PyPI - Downloads](https://img.shields.io/pypi/dm/narpyn?color=blue&label=Downloads&logo=pypi&logoColor=gold)](https://pypi.org/project/narpyn/) [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/narpyn.svg?logo=python&label=Python&logoColor=gold)](https://pypi.org/project/narpyn/)                                                                                                                                                                                                                                                                                                                        |
| Meta    | [![Pre-commit enabled](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://pre-commit.com) [![Hatch project](https://img.shields.io/badge/%F0%9F%A5%9A-Hatch-4051b5.svg)](https://github.com/pypa/hatch) [![linting - Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff) [![code style - Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) [![types - Mypy](https://img.shields.io/badge/types-Mypy-blue.svg)](https://github.com/python/mypy) [![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://spdx.org/licenses/) |

</div>

Currently supported backends include OpenNARS for Applications (ONA).
